.. Django Categories documentation master file, created by
   sphinx-quickstart on Tue Oct  6 07:53:33 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Categories's documentation!
=============================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

